{ config, lib, pkgs, ... }:
let
  cfg = config.this.application.kitty;
  graphical = config.this.graphical;
in with lib; {
  options = {
    this.application.kitty = {
      enable = mkOption {
        default = graphical.enable;
        type = with types; bool;
      };
    };
  };

  config = mkIf cfg.enable {
    home-manager.users.james = {
      home.packages = with pkgs; [ kitty ];
      programs.kitty = {
        enable = true;
        font = {
          package = pkgs.hasklig;
          name = "Hasklig";
          size = 10;
        };
        settings = {
          scrollback_lines = 10000;
          enable_audio_bell = false;
          update_check_interval = 0;
          ## name: Catppuccin
          ## author: Pocco81 (https://github.com/Pocco81)
          ## license: MIT
          ## upstream: https://github.com/catppuccin/kitty/blob/main/catppuccin.conf
          ## blurb: Soothing pastel theme for the high-spirited!
          # The basic colors
          foreground = "#D9E0EE";
          background = "#1E1E2E";
          selection_foreground = "#D9E0EE";
          selection_background = "#575268";
          # Cursor colors
          cursor = "#F5E0DC";
          cursor_text_color = "#1E1E2E";
          # URL underline color when hovering with mouse
          url_color = "#F5E0DC";
          # kitty window border colors
          active_border_color = "#C9CBFF";
          inactive_border_color = "#575268";
          bell_border_color = "#FAE3B0";
          # OS Window titlebar colors
          wayland_titlebar_color = "system";
          macos_titlebar_color = "system";
          #: Tab bar colors
          active_tab_foreground = "#F5C2E7";
          active_tab_background = "#575268";
          inactive_tab_foreground = "#D9E0EE";
          inactive_tab_background = "#1E1E2E";
          tab_bar_background = "#161320";
          # Colors for marks (marked text in the terminal)
          mark1_foreground = "#1E1E2E";
          mark1_background = "#96CDFB";
          mark2_foreground = "#1E1E2E";
          mark2_background = "#F5C2E7";
          mark3_foreground = "#1E1E2E";
          mark3_background = "#B5E8E0";
          #: The 16 terminal colors
          #: black
          color0 = "#6E6C7E";
          color8 = "#988BA2";
          #: red
          color1 = "#F28FAD";
          color9 = "#F28FAD";
          #: green
          color2 = "#ABE9B3";
          color10 = "#ABE9B3";
          #: yellow
          color3 = "#FAE3B0";
          color11 = "#FAE3B0";
          #: blue
          color4 = "#96CDFB";
          color12 = "#96CDFB";
          #: magenta
          color5 = "#F5C2E7";
          color13 = "#F5C2E7";
          #: cyan
          color6 = "#89DCEB";
          color14 = "#89DCEB";
          #: white
          color7 = "#D9E0EE";
          color15 = "#D9E0EE";
        };
      };
    };
  };
}
